searchData={"items":[{"type":"module","title":"BEAMNotify","doc":"Send a message to the BEAM from a shell script","ref":"BEAMNotify.html"},{"type":"function","title":"BEAMNotify.bin_path/0","doc":"Return the path to `beam_notify`","ref":"BEAMNotify.html#bin_path/0"},{"type":"function","title":"BEAMNotify.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"BEAMNotify.html#child_spec/1"},{"type":"function","title":"BEAMNotify.env/1","doc":"Return the OS environment needed to call `$BEAM_NOTIFY`\n\nThis returns a map that can be passed directly to `System.cmd/3` via its\n`:env` option.\n\nThis function can be passed different things based on what's convenient.\n\n1. If you're setting up `child_spec`'s for a supervision tree and need the\n   environment to pass in another `child_spec`, call this with the same\n   options that you'd pass to `start_link/1`. This is a very common use.\n\n2. If you called `start_link/1` manually and have the pid, call it with\n   the pid.\n\n3. If you only have the name that was passed to `start_link/1`, then call\n   it with the name. The name alone is insufficient for returning the\n   `$BEAM_NOTIFY_OPTIONS` environment variable, so the `BEAMNotify`\n   GenServer must be running. If you're in a chicken-and-egg situation\n   where you're setting up a supervision tree, but it hasn't been started\n   yet, see option 1.","ref":"BEAMNotify.html#env/1"},{"type":"function","title":"BEAMNotify.start_link/1","doc":"Start the BEAMNotify message receiver","ref":"BEAMNotify.html#start_link/1"},{"type":"type","title":"BEAMNotify.dispatcher/0","doc":"Callback for dispatching notifications\n\nBEAMNotify calls the dispatcher function whenever a message comes in. The\nfirst parameter is the list of arguments passed to `$BEAM_NOTIFY`. The\nsecond argument is a map containing environment variables. Whether or\nnot the map is populated depends on the options to `start_link/1`.","ref":"BEAMNotify.html#t:dispatcher/0"},{"type":"type","title":"BEAMNotify.options/0","doc":"BEAMNotify takes the following options\n\n* `:name` - a unique name for this notifier. This is required if you expect\n  to run multiple BEAMNotify GenServers at a time.\n* `:dispatcher` - a function to call when a notification comes in\n* `:path` - the path to use for the named socket. A path in the system\n   temporary directory is the default.\n* `:mode` - the permissions to apply to the socket. Should be an octal number\n   eg: 0o660 for read/write owner/group, no access to everyone else\n* `:report_env` - set to `true` to report environment variables in addition\n   to commandline argument. Defaults to `false`\n* `:recbuf` - receive buffer size. If you're sending a particular large\n   amount of data and getting errors from `:erlang.binary_to_term(data)`, try\n   making this bigger. Defaults to 8192.","ref":"BEAMNotify.html#t:options/0"},{"type":"extras","title":"BEAMNotify","doc":"# BEAMNotify\n\n[![Hex version](https://img.shields.io/hexpm/v/beam_notify.svg \"Hex version\")](https://hex.pm/packages/beam_notify)\n[![API docs](https://img.shields.io/hexpm/v/beam_notify.svg?label=hexdocs \"API docs\")](https://hexdocs.pm/beam_notify/BEAMNotify.html)\n[![CircleCI](https://circleci.com/gh/nerves-networking/beam_notify.svg?style=svg)](https://circleci.com/gh/nerves-networking/beam_notify)\n\nSend a message to the BEAM from a shell script\n\nThis is one solution sending notifications from non-BEAM programs into Elixir.\n`BEAMNotify` lets you set up a GenServer that listens for notifications from\nshell scripts or anything that can invoke an OS process. Communication is via a\nUnix Domain socket. Messages are limited to strings that passed via commandline\narguments or the environment to the `beam_notify` binary.\n\nThere are, of course, other ways of solving this problem. Some non-Elixir\nprograms already expose Unix domain or TCP socket interfaces for communication.\nThis might be a better choice. You could also use\n[erl_call](http://erlang.org/doc/man/erl_call.html) or write a [C\nnode](http://erlang.org/doc/apps/erl_interface/ei_users_guide.html#introduction)\nand communicate over distributed Erlang.","ref":"readme.html"},{"type":"extras","title":"Overview - BEAMNotify","doc":"`BEAMNotify` would typically be added to a supervision tree in your program.\nOptions to `BEAMNotify` specify things like its name, a dispatch function to\ncall, and other things.\n\nThe shell script (or any program) needs to call the `beam_notify` program\nsupplied by this library. The message is passed via commandline arguments or\nenvironment variables (see `:report_env` option).\n\nSince `beam_notify` needs to know how to connect to the appropriate\n`BEAMNotify` GenServer (there may be more than one), the shell script must pass\nsome options. To make this easy, `BEAMNotify` provides two environment\nvariables by calling `BEAMNotify.env/1`:\n\n1. `$BEAM_NOTIFY` - the absolute path to the `beam_notify` executable\n2. `$BEAM_NOTIFY_OPTIONS` - how `beam_notify` should connect\n\nIn the shell script, run `$BEAM_NOTIFY` and pass it any arguments that you want\nsend up. `BEAMNotify` reports environment variables too.\n\nIf it is not possible to pass the `$BEAM_NOTIFY*` environment variables through\nto your script due to a restricted shell environment, see the restricted shell\nsection below.\n\nBack in Elixir, whenever a proper message is received, `BEAMNotify` will call\nthe dispatch function. The dispatch function is responsible for forwarding on\nmessages however makes sense in your application. If handling is simple, you can\nprocess them in the dispatch function. You could also publish them through\n`Phoenix.PubSub` or another pubsub service. `BEAMNotify` only handles strings,\nso if you want to be fancier with your messages or filter them, you'll have to\nadd that to your dispatcher function.\n\nIt is important to keep in mind that the amount of data that can be sent in a\nnotification is limited by the transport and by OS limits on commandline\narguments. Suffice it to say that this is not intended for file transfer.","ref":"readme.html#overview"},{"type":"extras","title":"Example - BEAMNotify","doc":"What we're going to do is create a script that sends a message to Elixir.\nFirst, make sure that you have `:beam_notify` by either cloning this project or\ncreating a test Elixir project (`mix new ...`) and adding it to the `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:beam_notify, \"~> 0.2.0\"}\n  ]\nend\n```\n\nNow open an editor and create `simple.sh` with the following contents:\n\n```sh\n#!/bin/sh\n\necho \"This is simple.sh\"\n\n$BEAM_NOTIFY Hello world\n```\n\nStart up Elixir with `iex -S mix`:\n\n```elixir\n# Get the PID that's running the IEx console\niex> us = self()\n#PID<0.204.0>\n\n# Start a BEAMNotify GenServer. The dispatcher function sends a tuple with the\n# arguments and environment passed in from the shell script.\niex> BEAMNotify.start_link(name: \"sulu\", report_env: true, dispatcher: &send(us, {&1, &2}))\n{:ok, #PID<0.211.0>}\n\n# Run the shell script. We're doing this from Elixir, but you\n# can also grab the environment by calling `BEAMNotify.env/1` and run it\n# in another terminal window.\niex> System.cmd(\"/bin/sh\", [\"simple.sh\"], env: BEAMNotify.env(\"sulu\"))\n{\"This is simple.sh\\n\", 0}\n\n# See what was sent\niex> flush\n{[\"Hello\", \"world\"], %{...}}\n```","ref":"readme.html#example"},{"type":"extras","title":"Supervision example - BEAMNotify","doc":"Here's a code snippet of starting a hypothetical non-Elixir program that needs\nto send messages back to Elixir. This code is part of a [module-based\nsupervisor](https://hexdocs.pm/elixir/Supervisor.html#module-module-based-supervisors),\nbut this isn't necessary. Two GenServers are started: one for `BEAMNotify` and\none to start and monitor the non-Elixir program using\n[`MuonTrap.Daemon`](https://hexdocs.pm/muontrap/MuonTrap.Daemon.html).\n\nNote how `BEAMNotify.env/1` is used to pass the proper environment to the\nprogram.\n\n```elixir\n  @impl Supervisor\n  def init(_) do\n    beam_notify_options = [name: \"my_beam\", dispatcher: &Some.function/2]\n    children = [\n      {BEAMNotify, beam_notify_options},\n      {MuonTrap.Daemon,\n       [\n         \"/path/to/program\",\n         [\"-s\", \"script_calling_beam_notify.sh\"],\n         [log_output: :debug, env: BEAMNotify.env(beam_notify_options)]\n       ]}\n    ]\n\n    opts = [strategy: :one_for_one]\n    Supervisor.start_link(children, opts)\n  end\n```\n\nIf you're lucky, it might be sufficient to call `BEAMNotify.bin_path/0` to get\nthe path to the `beam_notify` program and pass that directly to the non-Elixir\nprogram. You'll still need to set the environment for `beam_notify` to work. On\nthe bright side, this will skip out having your system start `bash` on each\nnotification.","ref":"readme.html#supervision-example"},{"type":"extras","title":"Restricted shell environments - BEAMNotify","doc":"Some programs clear the OS environment before running programs as a security\nprecaution. It's still possible send messages to Elixir.\n\nYou'll need to know the path to the `beam_notify` binary and have a place to put\nthe communications socket that both Elixir and the `beam_notify` binary can\nopen. In this example, the socket will be created as\n`/tmp/my_beam_notify_socket`. In Elixir, the `BEAMNotify` child_spec might look\nlike this:\n\n```elixir\n{BEAMNotify, name: \"any name\", path: \"/tmp/my_beam_notify_socket\", dispatcher: &Some.function/2}\n```\n\nFor the script, here's a sample for Nerves devices where code is installed under\n`/srv/erlang`.\n\n```sh\n#!/bin/sh\n\nBEAM_NOTIFY=$(ls /srv/erlang/lib/beam_notify-*/priv/beam_notify)\n\n$BEAM_NOTIFY -p /tmp/my_beam_notify_socket -- hello\n```\n\nThe arguments following the `--` are passed. The `-p /tmp/my_beam_notify_socket`\npart will be dropped.\n\nArguments are only parsed (and dropped) if `$BEAM_NOTIFY_OPTIONS` isn't defined.\nIn other words, `$BEAM_NOTIFY_OPTIONS` takes precedence.","ref":"readme.html#restricted-shell-environments"},{"type":"extras","title":"License - BEAMNotify","doc":"This library is covered by the Apache 2 license.","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v1.1.1 - Changelog","doc":"* Fixes\n  * Fix compilation on systems with Erlang installed in a directory with spaces","ref":"changelog.html#v1-1-1"},{"type":"extras","title":"v1.1.0 - Changelog","doc":"This release fixes warnings when compiled with Elixir 1.15. It removes support\nfor Elixir 1.9.","ref":"changelog.html#v1-1-0"},{"type":"extras","title":"v1.0.0 - Changelog","doc":"This release has no changes except for the version number.","ref":"changelog.html#v1-0-0"},{"type":"extras","title":"v0.2.2 - Changelog","doc":"* New features\n  * Add `:mode` option for setting socket file permissions. Thanks to Ed\n    Wildgoose for this feature.","ref":"changelog.html#v0-2-2"},{"type":"extras","title":"v0.2.1 - Changelog","doc":"This release only cleans up Makefile prints and bumps dependencies. No code\nchanges were made.","ref":"changelog.html#v0-2-1"},{"type":"extras","title":"v0.2.0 - Changelog","doc":"* New features\n  * Support for explicitly passing the socket path - this enables use in\n    restricted environments where it's impossible or hard to pass parameters\n    through environment variables\n  * Reporting the environment is off by default. See the `:report_env` option\n  * Default socket paths are obfuscated. This also removes OS-specific\n    character-set issues and length limitations","ref":"changelog.html#v0-2-0"},{"type":"extras","title":"v0.1.0 - Changelog","doc":"Initial release to hex.","ref":"changelog.html#v0-1-0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}